@@ -1,6 +1,5 @@
 import abc
 import logging
-
 import time
 from typing import Optional, Dict, Any
 
@@ -9,6 +8,10 @@ import requests
 logger = logging.getLogger(__name__)
 
 
+class ResistantApiException(Exception):
+    pass
+
+
 class ApiClientBase(abc.ABC):
     MAX_NUM_RETRIES_POLL = 10
     MAX_SLEEP_TIMEOUT = 32
@@ -25,12 +28,15 @@ class ApiClientBase(abc.ABC):
             self._s3_session.proxies.update(https=proxy)
 
     def _submit(self, url: str, data: bytes, query_id: str = "", pipeline_configuration: Optional[str] = None,
-                max_num_retries: int = MAX_NUM_RETRIES_SUBMIT) -> str:
-        additional_args = {}
+                max_num_retries: int = MAX_NUM_RETRIES_SUBMIT, enable_decision: bool = False) -> str:
+        body = {"query_id": query_id}
         if pipeline_configuration:
-            additional_args['pipeline_configuration'] = pipeline_configuration
+            body['pipeline_configuration'] = pipeline_configuration
+        if enable_decision:
+            body['enable_decision'] = True
+
         for i in range(max_num_retries):
-            response = self._api_session.post(url, json={"query_id": query_id, **additional_args})
+            response = self._api_session.post(url, json=body)
             if response.status_code == 200:
                 response_data = response.json()
                 response_put = self._s3_session.put(response_data["upload_url"], data=data, headers={'Content-Type': 'application/octet-stream'})
@@ -55,3 +61,11 @@ class ApiClientBase(abc.ABC):
             else:
                 response.raise_for_status()
         raise RuntimeError("Submission not found, reached max number of retries.")
+
+    def _get_response_body(self, response: requests.Response) -> Optional[dict]:
+        if response.status_code == 200:
+            return response.json()
+        elif response.status_code == 404:
+            return None
+        else:
+            response.raise_for_status()
